# -*- coding: utf-8 -*-
# Generated by Django 1.9.5 on 2016-05-25 10:11
from __future__ import unicode_literals

import ditto.twitter.models
from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('twitter', '0036_auto_20160505_1156'),
    ]

    operations = [
        migrations.AddField(
            model_name='user',
            name='avatar',
            field=models.ImageField(blank=True, default='', upload_to=ditto.twitter.models.User.avatar_upload_path),
        ),
    ]
